@@ -58,6 +58,25 @@ namespace Lum {
 
       extern CairoDriver cairoDriver;
 
+#if defined(CAIRO_HAS_WIN32_SURFACE)
+      class CairoWin32Driver : public Base::Driver
+      {
+      public:
+        CairoWin32Driver();
+
+        OS::Display* CreateDisplay() const;
+        OS::Window* CreateWindow() const;
+        OS::Bitmap* CreateBitmap(size_t width, size_t height) const;
+        OS::DrawInfo* CreateDrawInfo(OS::Window* window);
+        OS::DrawInfo* CreateDrawInfo(OS::Bitmap* bitmap);
+        OS::Font* CreateFont() const;
+        OS::Tray* CreateTray() const;
+        Images::Factory* CreateImageFactory(OS::Display* display) const;
+      };
+
+      extern CairoWin32Driver cairoWin32Driver;
+#endif
+      
 #if defined(CAIRO_HAS_XLIB_SURFACE)
       class CairoX11Driver : public Base::Driver
       {
