@@ -33,6 +33,9 @@ namespace Lum {
         size_t              width;
         size_t              height;
 
+      private:
+        void Draw(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+
       public:
         TextImage(Display::ImageIndex image);
 
@@ -41,7 +44,9 @@ namespace Lum {
         bool GetAlpha() const;
         unsigned long GetDrawCap() const;
 
-        void Draw(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+        void DrawScaled(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+        void DrawStretched(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+        void Draw(OS::DrawInfo *draw, int x, int y);
       };
 
 
@@ -52,6 +57,9 @@ namespace Lum {
         size_t           width;
         size_t           height;
 
+      private:
+        void Draw(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+
       public:
         TextStockImage(Theme::StockImage image);
 
@@ -60,7 +68,9 @@ namespace Lum {
         bool GetAlpha() const;
         unsigned long GetDrawCap() const;
 
-        void Draw(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+        void DrawScaled(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+        void DrawStretched(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+        void Draw(OS::DrawInfo *draw, int x, int y);
       };
 
       class TextFill : public Fill
