@@ -36,11 +36,16 @@ namespace Lum {
       class LUMAPI DisplayManager : public Manager::DisplayManager
       {
       private:
+        DisplayState     displayState;
+        Model::ActionRef displayStateChangeAction;
         Model::ActionRef timerAction;
 
       public:
         DisplayManager();
 
+        void SetDisplayState(DisplayState displayState);
+        DisplayState GetDisplayState() const;
+        Model::Action* GetDisplayStateChangeAction() const;
         bool AllowScreenBlanking(bool blankable);
 
         void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
