@@ -175,9 +175,9 @@ namespace Lum {
       //@{
       virtual bool GetMousePos(int& x, int& y) const = 0;
       virtual bool CursorIsIn() const = 0;
-      virtual bool IsDoubleClicked() const = 0;
-      virtual bool IsTrippleClicked() const = 0;
       virtual bool HasFocus() const = 0;
+      virtual bool IsDoubleClicked() const = 0;
+      virtual const MouseEvent& GetLastButtonClickEvent() const = 0;
       //@}
 
       /**
