@@ -31,17 +31,6 @@ namespace Lum {
    */
   class LUMAPI PercentBar : public Control
   {
-  public:
-    class Prefs : public Object::Prefs
-    {
-    public:
-      OS::FrameRef valueBox;
-
-    public:
-      Prefs(const std::wstring& name);
-      void Initialize();
-    };
-
   private:
     Model::DoubleDataStreamRef model;
     bool                       horizontal;
