@@ -123,6 +123,12 @@ namespace Lum {
                           Lum::Model::Header* header=NULL);
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+    
+    static TableIndexValueButton* Create(const std::wstring& label,
+                                         Base::Model* model,
+                                         Lum::Model::Table* table,
+                                         bool horizontalFlex=false,
+                                         bool verticalFlex=false);
   };
 }
 
