@@ -24,16 +24,17 @@ namespace Lum {
     Action::Action(const Desc& description, Model::Action *action)
      : description(description),
        action(action),
-       type(normal)
+       type(normal),
+       opensDialog(false)
     {
       assert(action!=NULL);
     }
 
-    Action* Action::SetType(Type type)
+    Action& Action::SetType(Type type)
     {
       this->type=type;
 
-      return this;
+      return *this;
     }
 
     Action::Type Action::GetType() const
@@ -50,6 +51,18 @@ namespace Lum {
     {
       return description;
     }
+
+    Action& Action::SetOpensDialog()
+    {
+      opensDialog=true;
+
+      return *this;
+    }
+
+    bool Action::GetOpensDialog() const
+    {
+      return opensDialog;
+    }
   }
 }
 
