@@ -35,6 +35,8 @@ namespace Lum {
 #if defined(CAIRO_HAS_XLIB_SURFACE)
         display=cairo_xlib_surface_get_display(surface);
         drawable=cairo_xlib_surface_get_drawable(surface);
+#elif defined(CAIRO_HAS_WIN32_SURFACE)
+        dc=cairo_win32_surface_get_dc(surface);
 #endif
 
         draw=driver->CreateDrawInfo(this);
