@@ -37,6 +37,8 @@
 #include <Lum/OS/Cairo/Bitmap.h>
 #include <Lum/OS/Cairo/Font.h>
 
+#include <iostream> 
+
 namespace Lum {
   namespace OS {
     namespace Cairo {
@@ -519,6 +521,56 @@ namespace Lum {
         cairo_restore(draw->cairo);
       }
 
+#if defined(CAIRO_HAS_WIN32_SURFACE)
+      Win32DrawInfo::Win32DrawInfo(OS::Window* window)
+      : DrawInfo(window)
+      {
+        dc=GetDC(dynamic_cast<OS::Win32::Window*>(window)->window);
+
+        
+        surface=cairo_win32_surface_create(dc);
+
+        deleteSurface=true;
+        cairo=cairo_create(surface);
+
+        std::cout << "DrawInfo/Window :" << dc << " " << surface << " " << cairo << std::endl;
+        
+        SetDefaults();
+      }
+
+      Win32DrawInfo::Win32DrawInfo(OS::Bitmap* bitmap)
+      : DrawInfo(bitmap)
+      {
+        surface=dynamic_cast<Bitmap*>(bitmap)->surface;
+        deleteSurface=false;
+
+        dc=dynamic_cast<Bitmap*>(bitmap)->dc;
+
+        cairo=cairo_create(surface);
+
+        std::cout << "DrawInfo/Bitmap :" << dc << " " << surface << " " << cairo << std::endl;
+        
+        SetDefaults();
+      }
+
+      /**
+        Deinitializes the drawInfo
+      */
+      Win32DrawInfo::~Win32DrawInfo()
+      {
+        cairo_destroy(cairo);
+        if (deleteSurface) {
+          cairo_surface_destroy(surface);
+        }
+      }
+
+      void Win32DrawInfo::GetRGBValue(Color color, double &r, double &g, double &b)
+      {
+        assert(false);
+      }
+
+#endif
+      
 #if defined(CAIRO_HAS_XLIB_SURFACE)
       X11DrawInfo::X11DrawInfo(OS::Window* window)
       : DrawInfo(window)
