@@ -192,7 +192,7 @@ namespace Lum {
 
             msg->input_window=dynamic_cast<X11::Window*>(window)->GetDrawable();
             msg->app_window=dynamic_cast<X11::Window*>(window)->GetDrawable();
-            msg->cmd=HILDON_IM_UPP;
+            msg->cmd=HILDON_IM_UP;
             msg->trigger=triggerType;
 
             if (XSendEvent(display->display,imWindow,False,NoEventMask,&event)==0) {
@@ -253,9 +253,9 @@ namespace Lum {
           else if (msg->type==HILDON_IM_CONTEXT_OPTION_CHANGED) {
             //std::cout << "HILDON_IM_CONTEXT_OPTION_CHANGED" << std::endl;
           }
-          else if (msg->type==HILDON_IM_CONTEXT_CLEAR_STICKY) {
+          /*else if (msg->type==HILDON_IM_CONTEXT_CLEAR_STICKY) {
             //std::cout << "HILDON_IM_CONTEXT_CLEAR_STICKY" << std::endl;
-          }
+          }*/
           else if (msg->type==HILDON_IM_CONTEXT_ENTER_ON_FOCUS) {
             //std::cout << "HILDON_IM_CONTEXT_ENTER_ON_FOCUS" << std::endl;
           }
