@@ -26,6 +26,10 @@
   #include <Lum/OS/Hildon/KeyboardManager.h>
 #endif
 
+#if defined(HAVE_LIB_OSSO)
+  #include <Lum/OS/Hildon/NetworkManager.h>
+#endif
+
 namespace Lum {
   namespace OS {
     namespace Manager {
@@ -55,6 +59,7 @@ namespace Lum {
           displayManager=new Lum::OS::Hildon::DisplayManager();
 #endif
         }
+
         return displayManager;
       }
 
@@ -65,11 +70,18 @@ namespace Lum {
           keyboardManager=new Lum::OS::Hildon::KeyboardManager();
 #endif
         }
+
         return keyboardManager;
       }
 
       NetworkManager* Repository::GetNetworkManager()
       {
+        if (networkManager==NULL) {
+#if defined(HAVE_LIB_OSSO)
+          networkManager=new Lum::OS::Hildon::NetworkManager();
+#endif
+        }
+
         return networkManager;
       }
     }
