@@ -69,7 +69,19 @@ namespace Lum {
 
     ProberImpl::ProberImpl()
     {
+
 // Primary
+    
+#if defined(LUM_HAVE_LIB_CAIRO) && defined(CAIRO_HAS_WIN32_SURFACE)
+      AddDriver(&Cairo::cairoWin32Driver);
+#endif
+
+#if defined(LUM_HAVE_LIB_CAIRO) && defined(CAIRO_HAS_XLIB_SURFACE)
+      AddDriver(&Cairo::cairoX11Driver);
+#endif
+
+// Secondary
+
 #if defined(LUM_HAVE_LIB_CARBON)
       AddDriver(&Carbon::carbonDriver);
 #endif
@@ -78,10 +90,6 @@ namespace Lum {
       AddDriver(&Win32::win32Driver);
 #endif
 
-#if defined(LUM_HAVE_LIB_CAIRO) && defined(CAIRO_HAS_XLIB_SURFACE)
-      AddDriver(&Cairo::cairoX11Driver);
-#endif
-
 #if defined(_MSC_VER)
   #if defined(HAVE_X11)
       AddDriver(&X11::x11Driver);
@@ -97,11 +105,11 @@ namespace Lum {
 #endif
 
 // Secondary
-
+/*
 #if defined(LUM_HAVE_LIB_CAIRO)
       AddDriver(&Cairo::cairoDriver);
 #endif
-
+*/
       char* tmp;
 
       tmp=setlocale(LC_ALL,"");
