@@ -24,6 +24,8 @@
 
 #include <Lum/Base/String.h>
 
+#include <Lum/OS/Base/Behaviour.h>
+
 #include <Lum/OS/Win32/DrawInfo.h>
 #include <Lum/OS/Win32/Image.h>
 #include <Lum/OS/Win32/Tray.h>
@@ -88,7 +90,7 @@ namespace Lum {
         void Trigger()
         {
           MSG msg;
-          
+
           while (::PeekMessage(&msg,NULL,0,0,PM_REMOVE)) {
             if (msg.message==WM_QUIT) {
               break;
@@ -102,7 +104,7 @@ namespace Lum {
           return false;
         }
       };
-      
+
       Display::Display()
        : selectObject(NULL),
          instance(0),
@@ -578,10 +580,12 @@ namespace Lum {
 
         eventLoop=new Win32EventLoop();
         eventLoop->AddSource(new Win32MsgEventSource(this));
-        
+
         //D.smallChess=d.CreateBitmapPattern(D.disablePattern,D.disableWidth,D.disableHeight);
         //D.bigChess=d.CreateBitmapPattern(D.bigChessPattern,D.bigChessWidth,D.bigChessHeight);
 
+        behaviour=new OS::Base::DefaultBehaviour();
+
         if (driver->GetDriverName()==L"Win32") {
           theme=new Win32Theme(this);
         }
@@ -626,7 +630,7 @@ namespace Lum {
 
         return true;
       }
-      
+
       void Display::Close()
       {
         //std::list<Window*>::iterator win;
@@ -652,7 +656,7 @@ namespace Lum {
         */
 
         DestroyWindow(appWindow);
-        
+
         delete eventLoop;
       }
 
