@@ -27,7 +27,7 @@
 #include <Lum/OS/Win32/Bitmap.h>
 #include <Lum/OS/Win32/Font.h>
 #include <Lum/OS/Win32/Window.h>
-
+//#include <iostream>
 namespace Lum {
   namespace OS {
     namespace Win32 {
@@ -395,7 +395,7 @@ namespace Lum {
 
       void DrawInfo::PushDash(const char* dashList, size_t len, DashMode mode)
       {
-	assert(dashList!=NULL && len>0);
+    assert(dashList!=NULL && len>0);
 
         DashEntry entry;
         //int       size,cap=CapButt,join=JoinBevel,line=0;
@@ -575,22 +575,24 @@ namespace Lum {
       void DrawInfo::DrawArc(int x, int y, int width, int height, int angle1, int angle2)
       {
         double a,b;
-        int    sx,sy,ex,ey,t;
+        int    sx,sy,ex,ey;
 
         if (angle1==0 && angle2==360*64) {
           /*ignore */ Arc(dc,x,y,x+width,y+height,0,0,0,0);
-        }
-        else {
-         /* Transformation to windows: absolute angle */
-         angle2=angle1+angle2;
+          return;
         }
 
         /* Swap angles, if necessary */
         if (angle1>angle2) {
-          t=angle2;
-          angle2=angle1;
-          angle1=t;
+          SetArcDirection(dc,AD_CLOCKWISE);
+          angle2=angle1+angle2;
         }
+        else {
+          angle1=angle1-angle2;
+          SetArcDirection(dc,AD_COUNTERCLOCKWISE);
+        }
+
+         /* Transformation to windows: absolute angle */
 
         /* Calculate radials */
         a=((angle1 / 64)*M_PI)/180.0;
@@ -607,21 +609,25 @@ namespace Lum {
       void DrawInfo::FillArc(int x, int y, int width, int height, int angle1, int angle2)
       {
         double a,b;
-        int    sx,sy,ex,ey,t;
+        int    sx,sy,ex,ey;
+
+        //std::cout << x << "," << y << " " << width << "x" << height << " " << angle1 << " " << angle2 << std::endl;
 
         if (angle1==0 && angle2==360*64) {
+          //std::cout << "Draw ellipse" << std::endl;
           /*ignore */ Ellipse(dc,x,y,x+width,y+height);
-        }
-        else {
-         /* Transformation to windows: absolute angle */
-         angle2=angle1+angle2;
+          return;
         }
 
         /* Swap angles, if necessary */
         if (angle1>angle2) {
-          t=angle2;
-          angle2=angle1;
-          angle1=t;
+          //std::cout << "=> Swapping angles" << std::endl;
+          SetArcDirection(dc,AD_CLOCKWISE);
+          angle2=angle1+angle2;
+        }
+        else {
+          angle1=angle1-angle2;
+          SetArcDirection(dc,AD_COUNTERCLOCKWISE);
         }
 
         /* Calculate radials */
@@ -633,6 +639,8 @@ namespace Lum {
         ex=x+width  / 2 +(int)(100*cos(b));
         ey=y+height / 2 -(int)(100*sin(b));
 
+        //std::cout << "=> " << sx << "x" << sy << " " << ex << "x" << ey << std::endl;
+
         /*ignore */ Pie(dc,x,y,x+width,y+height,sx,sy,ex,ey);
       }
 
