@@ -505,4 +505,21 @@ namespace Lum {
 
     ValueButton::Resync(model,msg);
   }
+  
+  TableIndexValueButton* TableIndexValueButton::Create(const std::wstring& label,
+                                                       Base::Model* model,
+                                                       Lum::Model::Table* table,
+                                                       bool horizontalFlex,
+                                                       bool verticalFlex)
+  {
+    TableIndexValueButton *control;
+    
+    control=new TableIndexValueButton(table);
+    
+    control->SetLabel(label);
+    control->SetModel(model);
+    control->SetFlex(horizontalFlex,verticalFlex);
+    
+    return control;
+  }                                                                          
 }
