@@ -26,7 +26,11 @@
 namespace Lum {
 
   WindowGroup::WindowGroup()
-  : men(NULL),main(NULL),tool(NULL),status(NULL),mainSeamless(false)
+  : men(NULL),
+    main(NULL),
+    tool(NULL),
+    status(NULL),
+    mainSeamless(false)
   {
     // no code
   }
